@@ -51,7 +51,7 @@ def excecuteElement(config,records,ps_delete_query):
     except (Exception, psycopg2.Error) as error:
         print("Error while connecting to PostgreSQL :", error)
         res = -1
-        writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteElement : " + str(error)+('**'*45)+'\n\n',root_directory_name="",dir_name = '_LOG_Postgres')
+        writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteElement : " + str(error)+'\n'+('**'*45)+'\n\n',root_directory_name="",dir_name = '_LOG_Postgres')
     finally:
         # closing database connection.
         if connection:
